### Full featured example

This page shows all available buttons and plugins that are included in the TinyMCE core package. There are more examples on how to use TinyMCE in the Wiki.

<p> <img src="media/logo.jpg" alt=" " hspace="5" vspace="5" width="250" height="48" align="right" /> TinyMCE is a platform independent web based Javascript HTML <strong>WYSIWYG</strong> editor control released as Open Source under LGPL by Moxiecode Systems AB. It has the ability to convert HTML TEXTAREA fields or other HTML elements to editor instances. TinyMCE is very easy to integrate into other Content Management Systems. </p> <p> We recommend <a href="http://www.getfirefox.com" target="_blank">Firefox</a> and <a href="http://www.google.com" target="_blank">Google</a> <br /> </p>
[Show] [Hide] [Bold] [Get contents] [Get selected HTML] [Get selected text] [Get selected element] [Insert HTML] [Replace selection]